@@ -1,7 +1,7 @@
-import utils.utils as utils
-from utils.CustomTx import CustomTxType
-# import defichainUtils.utils.utils as utils
-# from defichainUtils.utils.CustomTx import CustomTxType
+# import utils.utils as utils
+# from utils.CustomTx import CustomTxType
+import defichainUtils.utils.utils as utils
+from defichainUtils.utils.CustomTx import CustomTxType
 from dataclasses import asdict
 
 
